@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,7 +8,6 @@
 
 #include "akregator_export.h"
 #include "articleviewerwebengine.h"
-#include <kpimtextedit/kpimtextedit-texttospeech.h>
 
 #include <QWidget>
 class QPrinter;
@@ -17,8 +16,13 @@ class KActionCollection;
 namespace KPIMTextEdit
 {
 class SlideContainer;
-class TextToSpeechWidget;
 }
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+namespace TextEditTextToSpeech
+{
+class TextToSpeechContainerWidget;
+}
+#endif
 
 namespace WebEngineViewer
 {
@@ -57,8 +61,8 @@ private:
     void printRequested(QWebEnginePage *page);
     WebEngineViewer::FindBarWebEngineView *mFindBarWebView = nullptr;
     ArticleViewerWebEngine *mArticleViewerNg = nullptr;
-#if KPIMTEXTEDIT_TEXT_TO_SPEECH
-    KPIMTextEdit::TextToSpeechWidget *const mTextToSpeechWidget;
+#ifdef HAVE_KTEXTADDONS_TEXT_TO_SPEECH_SUPPORT
+    TextEditTextToSpeech::TextToSpeechContainerWidget *const mTextToSpeechWidget;
 #endif
     KPIMTextEdit::SlideContainer *const mSliderContainer;
     WebEngineViewer::TrackingWarningWidget *const mTrackingWarningWidget;
