@@ -8,8 +8,6 @@
 
 #pragma once
 
-#include <kparts/browserextension.h>
-
 #include <QUrl>
 
 #include "akregator_export.h"
@@ -39,12 +37,6 @@ public:
     Q_REQUIRED_RESULT QUrl url() const;
     void setUrl(const QUrl &url);
 
-    Q_REQUIRED_RESULT KParts::OpenUrlArguments args() const;
-    void setArgs(const KParts::OpenUrlArguments &args);
-
-    Q_REQUIRED_RESULT KParts::BrowserArguments browserArgs() const;
-    void setBrowserArgs(const KParts::BrowserArguments &args);
-
     Q_REQUIRED_RESULT Options options() const;
     void setOptions(Options options);
 
@@ -59,11 +51,8 @@ public:
 private:
     int m_frameId = -1;
     QUrl m_url;
-    KParts::OpenUrlArguments m_args;
-    KParts::BrowserArguments m_browserArgs;
     Options m_options;
     bool m_inBackground = false;
     bool m_wasHandled = false;
 };
 } // namespace Akregator
-
